@@ -1,9 +1,9 @@
 from __future__ import annotations
 
 from enum import Enum
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Optional, Tuple
 
-from pydantic import ConfigDict
+from pydantic import ConfigDict, Field
 
 from seekrai.types.abstract import BaseModel
 
@@ -33,6 +33,13 @@ class ObjectType(str, Enum):
     Model = "model"
 
 
+class LogProbs(BaseModel):  # OpenAI style
+    text_offset: List[int] = Field(default_factory=list)
+    token_logprobs: List[Optional[float]] = Field(default_factory=list)
+    tokens: List[str] = Field(default_factory=list)
+    top_logprobs: List[Optional[Dict[str, float]]] = Field(default_factory=list)
+
+
 class LogprobsPart(BaseModel):
     # token list
     tokens: List[str | None] | None = None
@@ -51,6 +58,13 @@ class DeltaContent(BaseModel):
     content: str | None = None
 
 
+class DeltaLogProbs(BaseModel):
+    text_offset: int | None = None
+    token_logprob: float | None = None
+    token: str | None = None
+    top_logprobs: Dict[str, float] | None = None
+
+
 class SeekrFlowRequest(BaseModel):
     model_config = ConfigDict(arbitrary_types_allowed=True)
 
@@ -58,6 +72,11 @@ class SeekrFlowRequest(BaseModel):
     url: str
     headers: Dict[str, str] | None = None
     params: Dict[str, Any] | None = None
-    files: Dict[str, Any] | None = None
+    files: (
+        Dict[str, Any]
+        | List[Tuple[str, Tuple[str, Any, Optional[str]]]]
+        | List[Tuple[str, Any]]
+        | None
+    ) = None
     allow_redirects: bool = True
     override_headers: bool = False
