@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+from datetime import datetime
 from enum import Enum
 from typing import List, Literal
 
@@ -29,10 +30,12 @@ class ModelResponse(BaseModel):
     # object type
     object: Literal[ObjectType.Model]
     created: int | None = None
+    created_at: datetime | None = None
     # model type
     type: ModelType | None = None
     name: str | None = None
     bytes: int | None = None
+    model_type: str | None = None
     # # model creator organization
     # organization: str | None = None
     # # link to model resource
